@@ -90,6 +90,24 @@ class statsnz:
             req = req['properties']
             req = req['UR2021_V1_00_NAME']
 
+            return req
+
+        except Exception as e:
+
+            req = "request_error: " + str(e)
+
+            return req
+
+    def get_custom_layer(self, layer_id, lat, long):
+        """
+            Specify an area layer for use. Response as JSON.
+        """
+        try:
+
+
+            req = requests.get("https://datafinder.stats.govt.nz/services/query/v1/vector.json?key={}&layer={}&x={}&y={}&max_results=3&radius=10000&geometry=true&with_field_names=true".format(self.key,layer_id,long,lat)).json()
+
+
             return req
 
         except Exception as e:
